package com.example.smartlab.api

import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flow
import okio.IOException

//в этом классе описываются все функции, объявленные в Repository
class RepositoryImpl (
    private val api: Api//Переменная интерфейса Api
): Repository{
    //попытка отправки и обработка ошибок
    override suspend fun sendCodeToEmail(email: String): Flow<Result<String>> {
        return flow{
            val request = try{
                api.sendCodeToEmail(email)
            }
            catch(e: Exception){
                e.printStackTrace()
                emit( Result.Error(message = "Don't send code"))
                return@flow
            }
            //обёртка в пользовательский класс
            emit(Result.Success(request))
        }
    }

    override suspend fun signIn(email: String, code: String): Flow<Result<String>> {
        return flow{
            val request = try{
                api.signIn(email, code)
            }
            catch(e: IOException){
                e.printStackTrace()
                emit( Result.Error(message = "Failed to SignIn"))
                return@flow
            }
            //обёртка в пользовательский класс
            emit(Result.Success(request))
        }
    }

    override suspend fun getNews(): Flow<Result<List<News>>> {
        return flow{
            val newsFromApi = try{
                api.getNews()
            }
            catch(e: Exception){
                e.printStackTrace()
                emit( Result.Error(message = "Failed to get news"))
                return@flow
            }
            //обёртка в пользовательский класс
            emit(Result.Success(newsFromApi))
        }
    }
}