package com.example.smartlab.api

import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory

//объект для перехвата сообщений в LogCat, чтобы понимать, что происходит

//статическая переменная универсального подключения к апи
//молифицированный экземпляр объекта
object RetrofitInstance {
    /** Библиотека HttpLoggingInterceptor является частью OkHttp, но поставляется отдельно от неё.
    Перехватчик следует использовать в том случае, когда вам действительно нужно изучать логи ответов сервера.
    По сути библиотека является сетевым аналогом привычного LogCat.*/


    //новый перехватчик.приложить{ уровень=перехватчик.уровень.тело }
    private val interceptor: HttpLoggingInterceptor = HttpLoggingInterceptor().apply {
        level = HttpLoggingInterceptor.Level.BODY
    }

    /** OkHttp предоставляет простой, легкий в использовании API для выполнения HTTP‑запросов,
    включая поддержку протоколов HTTP/1.1 и HTTP/2. Библиотека поддерживает все стандартные методы HTTP
    и может легко обрабатывать несколько одновременных запросов, а также предоставляет расширенные возможности:
    кэширование запросов/ответов, объединение подключений в пул (connection pooling), аутентификация и др.*/

    //новый http клиент.закрепить().привязать новый перехватчик(перехватчик)
    //.закончить()
    private val client: OkHttpClient = OkHttpClient.Builder()
        .addInterceptor(interceptor)
        .build()
    //переменная апи интерфейса апи - модификация. закрепить()
    //добавить json конвертацию
    //добавить ссылку
    //добавить клиента с перехватчиком логов
    //закончить()
    //создать

    val apiJson: Api = Retrofit.Builder()
        .addConverterFactory(GsonConverterFactory.create())
        .baseUrl(Api.BASE_URL)
        .client(client)
        .build()
        .create(Api::class.java)

    /*val api: Api = Retrofit.Builder()
        .addConverterFactory(ScalarsConverterFactory.create())
        .baseUrl(Api.BASE_URL)
        .client(client)
        .build()
        .create(Api::class.java)*/
}