package com.example.smartlab.screens

import android.annotation.SuppressLint
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.ImageBitmap
import androidx.compose.ui.res.imageResource
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.example.smartlab.R
import com.example.smartlab.viewmodel.ViewModelMain

@SuppressLint("UnrememberedMutableState")
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun LogIn(navController: NavHostController, viewModel: ViewModelMain, mail: MutableState<String>) {
        Column (modifier = Modifier
            .fillMaxSize(1f)
            .background(color = Color.White),
        horizontalAlignment = Alignment.CenterHorizontally){
        Row (modifier = Modifier
            .fillMaxWidth(1f)
            .padding(top = 55.dp),
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.Center) {
            Image(
                bitmap = ImageBitmap.imageResource(R.drawable.true_hello),
                contentDescription = "Hello",
                modifier = Modifier
                    .fillMaxSize(0.1f)
                    .padding(end = 10.dp)
            )
            Text(text = "Добро пожаловать!", fontSize = 31.sp)
        }
        Text(text = "Войдите, чтобы пользоваться функциями приложения!", fontSize = 16.sp,
            modifier = Modifier.padding(start=35.dp, end=35.dp, bottom=40.dp))
        Row(horizontalArrangement = Arrangement.Start,
            modifier = Modifier.fillMaxWidth(1f)){
            Text(text = "Вход по E-mail", fontSize = 15.sp, color = Color.Gray,
                modifier = Modifier.padding(start=35.dp))
        }
            TextField(value = mail.value, onValueChange = {newtext -> mail.value = newtext},
                modifier = Modifier
                    .fillMaxWidth(0.82f)
                    .padding(bottom = 30.dp),
                keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Email),
                placeholder = {Text("example@mail.ru")},
                colors = TextFieldDefaults.textFieldColors(
                    unfocusedPlaceholderColor = Color.Gray,
                    focusedPlaceholderColor = Color.Gray)
            )

            var color = mutableStateOf(Color(0XFFE8EFFF))
            if(mail.value.isNotEmpty()){
                color.value = Color(0xFF1D68FF)
            }else{
                color.value = Color(0XFFE8EFFF)
            }
            Button(onClick =  {SendAndNavigate(viewModel, mail, navController)},
                modifier = Modifier
                    .fillMaxWidth(0.82f)
                    .padding(bottom = 230.dp),
                colors = ButtonDefaults.buttonColors(
                    containerColor = color.value
                )
            ) {

                Text(text = "Далее", color = Color.White)
            }

        Text(text = "Или войдите с помощью", fontSize = 15.sp, color = Color.Gray)
        Button(onClick = { /*TODO*/ }, modifier = Modifier
            .fillMaxWidth(0.82f)
            .padding(top = 13.dp),
            colors = ButtonDefaults.buttonColors(
                containerColor = Color(0xFFF5F5F9),
                contentColor = Color.Black
            )) {
            Text(text = "Войти с Яндекс")

        }
    }
}
fun SendAndNavigate(viewModel: ViewModelMain, mail: MutableState<String>, navController: NavHostController){
    try{
        viewModel.sendCodeToEmail(mail.value)
        navController.navigate("code_from_email")}
    catch(e: Exception){
        mail.value=""
    }
}