package com.example.smartlab.screens

import android.widget.Toast
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import coil.compose.AsyncImagePainter
import coil.compose.rememberAsyncImagePainter
import coil.request.ImageRequest
import coil.size.Size
import com.example.smartlab.api.News
import com.example.smartlab.viewmodel.ViewModelMain
import kotlinx.coroutines.flow.collectLatest

//@Preview
@Composable
fun TestsAsMain(navController: NavHostController, vm: ViewModelMain) {
    val explore = remember { mutableStateOf("") }
    Column(modifier = Modifier
        .fillMaxSize(1f)
        .background(Color.White)
        .padding(15.dp)){
        TextField(
            explore.value,
            { explore.value = it },
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Text),
            modifier = Modifier.fillMaxWidth(1f),
            placeholder = {Text("Искать анализы")}
        )
        Text(text = "Акции и новости", color = Color.Gray, modifier =
        Modifier.padding(vertical = 5.dp))
        vm.getNews()
        getNews(vm)

    }
}
@Composable
fun getNews(vm: ViewModelMain){
    val newsList = vm.news.collectAsState().value
    val context = LocalContext.current
    LaunchedEffect(key1 = vm.showErrorToastChannel) {
        vm.showErrorToastChannel.collectLatest { show ->
            if (show) {
                Toast.makeText(
                    context, "Error", Toast.LENGTH_SHORT
                ).show()
            }
        }
    }
    //Если лист пустой, то будет отображаться progress bar
    if (newsList.isEmpty()) {
        Box(
            modifier = Modifier.fillMaxSize(),
            contentAlignment = Alignment.Center
        ) {
            CircularProgressIndicator()
        }
    } else {
        //Иначе выводим данные в лист
        LazyColumn(
            modifier = Modifier.fillMaxSize(),
            horizontalAlignment = Alignment.CenterHorizontally,
            contentPadding = PaddingValues(16.dp)
        ) {
            items(newsList.size) { index ->
                New(newsList[index])
                Spacer(modifier = Modifier.height(16.dp))
            }
        }
    }
}
//Отрисовка одной новости
@Composable
fun New(res: News) {
    val imageState = rememberAsyncImagePainter(
        model = ImageRequest.Builder(LocalContext.current).data(res.image)
            .size(Size.ORIGINAL).build()
    ).state

    Column(
        modifier = Modifier
            .clip(RoundedCornerShape(20.dp))
            .height(420.dp)
            .fillMaxWidth()
            .background(MaterialTheme.colorScheme.primaryContainer)
    ) {

        if (imageState is AsyncImagePainter.State.Error) {
            Box(
                modifier = Modifier
                    .fillMaxWidth()
                    .height(400.dp),
                contentAlignment = Alignment.Center
            ) {
                CircularProgressIndicator()
            }
        }

        if (imageState is AsyncImagePainter.State.Success) {
            Image(
                modifier = Modifier
                    .fillMaxWidth()
                    .height(300.dp),
                painter = imageState.painter,
                contentDescription = res.name,
                contentScale = ContentScale.Crop
            )
        }

        Text(
            modifier = Modifier.padding(bottom = 10.dp),
            text = res.name,
            fontSize = 17.sp,
            fontWeight = FontWeight.SemiBold
        )
        Text(
            text = res.description,
            fontSize = 10.sp
        )
        Text(
            modifier = Modifier.padding(bottom = 5.dp),
            text = "${res.price} Руб.",
            fontSize = 16.sp
        )
    }
}